polygon_annulus_area

Function polygon_annulus_area 

fn polygon_annulus_area(polygon: &[Coords3], radii: [f64; 2]) -> f64
Area of a polygon of the plane z = constant kept inside the annulus of the axial face