fn planar_bounds(plane: &BoundedPlane) -> Vec<HalfSpace>Expand description
Half spaces bounding the face of a compartment, when all of them are planes. So a radial and a theta face are exactly clippable by half spaces, an axial face is not: its r bounds are cylinders, and that case is left to the caller.